============
Installation
============

At the command line::

    $ pip install fairy-slipper

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv fairy-slipper
    $ pip install fairy-slipper
